.. title:: Table of Contents

#########
qpsolvers
#########

.. **Release 1.6 -- April 9, 2021**

The goal of this library is to provide a unified interface to a wide array of
Quadratic Programming (QP) solvers available in Python.

.. toctree::

    installation.rst
    getting-started.rst
    supported-solvers.rst
